@@ -6,6 +6,7 @@ from qalx_orcaflex.bots.sim.functions import (
     begin_orcaflex,
     initialise_orcaflex_bot,
     post_process_orcaflex,
+    onload_orcaflex,
 )
 
 
@@ -18,6 +19,7 @@ class SimBot(Bot):
     Four step functions are pre-defined in `bots.sim.fuctions`:
         initialisation_function
         begin_function
+        onload_function
         preprocess_function
         process_function
 
@@ -31,3 +33,4 @@ class SimBot(Bot):
         self.begin_function = begin_orcaflex
         self.initialisation_function = initialise_orcaflex_bot
         self.postprocess_function = post_process_orcaflex
+        self.onload_function = onload_orcaflex
