@@ -108,3 +108,9 @@ def post_process_orcaflex(job: QalxJob):
         except AttributeError:
             pass
         del job.context["model"]
+
+
+def onload_orcaflex(job: QalxJob):
+    _options = job.entity.get_item_data("job_options")
+    if _options.delete_message_on_load:
+        job.delete_message()
