@@ -72,6 +72,8 @@ class OrcaFlexJobOptions:
         (default = 60)
     :param update_interval [int]: the number of seconds to wait between updating on
         model progress (default=5)
+    :param delete_message_on_load [bool]: will delete the queue message when the
+        simulation bot loads (default=False)
     """
 
     time_to_wait: int = 0
@@ -82,6 +84,7 @@ class OrcaFlexJobOptions:
     max_search_attempts: int = 10
     max_wait: int = 60
     update_interval: int = 5
+    delete_message_on_load: bool = False
 
 
 class JobState(Enum):
@@ -472,6 +475,7 @@ class RangeGraph:
         :param object_extra [ObjectExtra]:  (default=ObjectExtra())
         :param storm_duration_hours [float]:  (default=3.0)
         :param meta [ResultMeta]:  (default=ResultMeta())
+        :param as_file [bool]: (default=False)
 
     Available after the simulation has been post-processed:
         :param extracted [ExtractedRangeGraph]: the extracted
@@ -555,7 +559,7 @@ class TimeHistory:
         :param period [Period]:
         :param object_extra [ObjectExtra]:  (default=ObjectExtra())
         :param meta [ResultMeta]:  (default=ResultMeta())
-        :param as_file [bool]:
+        :param as_file [bool]: (default=False)
 
     Available after the simulation has been post-processed:
         :param extracted: ExtractedTimeHistory = ExtractedTimeHistory()
